﻿/*
 * font.h
 *
 * Created: 28.06.2013 11:43:16
 *  Author: Дмитрий
 */ 


#ifndef FONT_H_
#define FONT_H_

#include <avr/io.h>
#include <avr/pgmspace.h>

#define FONT_NORMAL 0
#define FONT_BOLD 1
#define FONT_SMALL 2

#define FONT_FLAG_MSBUP 0x80
#define FONT_FLAG_BLANK_BEFORE 0x02
#define FONT_FLAG_BLANK_AFTER 0x01


/*
  Устанавливает левую верхнюю позицию выводимого текста
  Set position of the text
*/
void text_set_pos(int8_t x, int8_t y);

/*
  Выбирает шрифт. Возможные варианты: FONT_NORMAL, FONT_BOLD, or FONT_SMALL
  Select font. One from FONT_NORMAL, FONT_BOLD, or FONT_SMALL
*/
void text_set_font(uint8_t code);

/*
  Выбирает произвольный шрифт, хранящийся во флеш-памяти (описание структуры шрифта смотри в font.c)
  Select font directly, by pointer to flash memory (see font.c for description of font structure)
*/
void text_set_user_font(PGM_P font);

/*
  Возвращает текущую гооризонтальную координату выводимого текста
  Current horizontal position
*/
int8_t text_get_X();

/*
  Возвращает текущую вертикальную координату выводимого текста
  Current vertical position
*/
int8_t text_get_Y();

/*
  Выводит строку, хранящуюся во флеш-памяти, на экран. Использует заданный шрифт и заданные координаты. Увеличивает горизонтальную координату на ширину отображённого текста.
  Автоматически преобразует UTF-8 русские символы: символы с А по Я - к кодам 0x80..0x9F, символы с а по я - к кодам 0xA0..0xBF, символ Ё - 0xC0,символ ё - 0xC1

  Print zero-terminated line from the flash memory. 

  xorMask:  0x00 - нормальное отображение/normal;  0xFF - инвертированное отображение/inverted
*/
void text_print_pgm(PGM_VOID_P pgmStr, uint8_t xorMask);

/*
  Выводит символ. Использует заданный шрифт и заданные координаты. Увеличивает горизонтальную координату на ширину отображённого текста
  Print character by code in current font

  xorMask:  0x00 - нормальное отображение/normal;  0xFF - инвертированное отображение/inverted
*/
void text_print_char(uint8_t ch, uint8_t xorMask);

/*
  Выводит число в десятичном представлении. 
  Print number in it's decimal representation.

  decPoint: если больше нуля, то добавляет точку на соответствующей от правого края позиции. adds decimal point at this position from right

  xorMask:  0x00 - нормальное отображение/normal;  0xFF - инвертированное отображение/inverted
*/
void text_print_num16(uint16_t number, uint8_t decPoint, uint8_t xorMask);

/*
  Выводит число со знаком в десятичном представлении. 
  Print signed number in it's decimal representation.

  decPoint: если больше нуля, то добавляет точку на соответствующей от правого края позиции. adds decimal point at this position from right

  xorMask:  0x00 - нормальное отображение/normal;  0xFF - инвертированное отображение/inverted
*/
void text_print_num16s(int16_t number, uint8_t decPoint, uint8_t xorMask);

/*
  Выводит байт в шестнадцатиричном представлении. 
  Print byte in it's hexadecimal representation.

  xorMask:  0x00 - нормальное отображение/normal;  0xFF - инвертированное отображение/inverted
*/
void text_print_hex(uint8_t hex, uint8_t xorMask);

/*
  Возвращает высоту выбранного шрифта
  Height of selected font
*/
int8_t text_height();

/*
  Высчитывает ширину строки в пикселях, на основе выбранного шрифта.
  Calculate string width in pixels, using selected font
*/
uint8_t text_width_pgm(PGM_VOID_P pgmStr);

/*
  Возвращает ширину символа в пикселях, на основе выбранного шрифта.
  Character width in pixels, using selected font
*/
uint8_t text_width_char(uint8_t ch);


#endif /* FONT_H_ */